@@ -67,6 +67,32 @@ nameday_calendar_jump_to_entry_by_date (GtkWidget *window,
 	}
 }
 
+static void
+nameday_calendar_cell_data_func (GtkTreeViewColumn *column,
+				 GtkCellRenderer *cell,
+				 GtkTreeModel *model,
+				 GtkTreeIter *iter,
+				 gpointer data)
+{
+	GtkTreeView *tree;
+	GtkTreeSelection *selection;
+
+	tree = (GtkTreeView *) data;
+	selection = gtk_tree_view_get_selection (tree);
+
+	if (gtk_tree_selection_iter_is_selected (selection, iter)) {
+		g_object_set (cell,
+			      "ellipsize", PANGO_ELLIPSIZE_NONE,
+			      "wrap-width", 700,
+			      NULL);
+	} else {
+		g_object_set (cell,
+			      "ellipsize", PANGO_ELLIPSIZE_END,
+			      "wrap-width", -1,
+			      NULL);
+	}
+}
+
 static gboolean
 nameday_calendar_filered_view_visible_func (GtkTreeModel *model,
 					    GtkTreeIter *iter,
@@ -331,6 +357,7 @@ nameday_calendar_window_create (NamedayDesktopApplet *priv)
 	GtkWidget *window, *vbox, *alignment, *pannable, *treeview, *menu_item, *search, *entry, *close;
 	GtkListStore *list_store;
 	GtkCellRenderer *renderer;
+	GtkTreeViewColumn *column;
 	GtkTreeModel *filter;
 	GdkColor style_color;
 	GtkEntryCompletion *completion;
@@ -419,8 +446,16 @@ nameday_calendar_window_create (NamedayDesktopApplet *priv)
 		      "ellipsize-set", TRUE,
 	              "foreground-gdk", &style_color,
 	              "foreground-set", TRUE,
+	              "wrap-mode", PANGO_WRAP_WORD,
 		      NULL);
 
+	column = gtk_tree_view_get_column (GTK_TREE_VIEW (treeview), 1);
+	gtk_tree_view_column_set_cell_data_func (column,
+						 renderer,
+						 nameday_calendar_cell_data_func,
+						 treeview,
+						 NULL);
+
 	/* search bar */
 	alignment = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
 	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0,
